Learn R Programming

TR8 (version 0.9.13)

ECOFLORA_df: ECOFLORA_df: local lookup table for Ecoflora species' url(s)

Description

This dataset is not ment to be directly accessed by the final user. It is imported by the ecoflora() function to extrapolate the correct URL for each species of interest and download the corresponding functional traits. This dataset is used as a lookup table from the ecoflora() function.

Arguments

docType

data

References

Please alwasy cite the database according to:

Fitter, A . H. and Peat , H. J., 1994, The Ecological Flora Database, J. Ecol., 82, 415-425.

Examples

Run this code
## observe the data for the first few species
head(ECOFLORA_df)

Run the code above in your browser using DataLab