Learn R Programming

TR8 (version 0.9.14)

available_tr8: A dataframe containing the traits available for download.

Description

The available_tr8 dataframe can be used as a reference in order to know which traits can be downloaded with the TR8 package.

Usage

data("available_tr8")

Arguments

Format

A data frame with the following variables:
short_code
contains the codes that should be used when using the tr8() function
description
contains a short description of the traits
db
indicates from which databases the traits will be downloaded

Details

This dataframe can be viewed by those users who want to use the tr8() function in a non-interactive way (i.e. not willing to use the GUI for selecting traits to be retrieved). The users should take note of the short_code used for the traits of interest, since these are the codes that should be passed to tr8 in the download_list parameter.

Examples

Run this code
data(available_tr8)
## Not run: 
# tr8(species_list=c("Salix alba","Populus nigra"),download_list=c("life_form_P"))
# ## End(Not run)

Run the code above in your browser using DataLab