R dataset
and store the result in a local file; this file could be
then used whenever the tr8() function is used in
order to speed up the process of retrieving traits data.
leda_download_to_local_directory(directory)leda_database.Rda
gWidgets
package, to let the user select a folder where the datasets
has to be stored.