Learn R Programming

TR8 (version 0.9.14)

pignatti: pignatti

Description

pignatti is a dataframe containing traits data for italian species

Arguments

Format

Contains the following traits data about Italian Flora species
Specie.Pignatti
: species name in the original dataset
numero
: numeric code
codice
: numeric code
nome.scientifico
: scientific name with authors
forma_biologica
: life form
corotipo
: distribution of species
L
: Ellenberg value for light
T
: Ellenberg value for temperature
C
: Ellenberg value for continentality
U
: Ellenberg value for soil humidity
R
: Ellenberg value for soil pH
N
: Ellenberg value for Nutrients in the soil
S
: Ellenberg value for soil salinity
Name.tnrs
: species name according to tnrs

References

Pignatti, S., Menegoni, P., Pietrosanti, S., 2005, Biondicazione attraverso le piante vascolari. Valori di indicazione secondo Ellenberg (Zeigerwerte) per le specie della Flora d'Italia. Braun-Blanquetia 39, Camerino, pp. 97.

Examples

Run this code
## inspect the first rows of the dataset
head(pignatti)

Run the code above in your browser using DataLab