Learn R Programming

TR8 (version 0.9.14)

traits_eco: Set of functional traits to be retrieved by Ecoflora.

Description

traits_eco defines a list containg pairs in the form short_name_of_the_trait = corresponding_code_in_Ecoflora At the moment the package does not download all the traits available at Ecoflora; curious users can expand the number of downloadable traits simply extending the list with other 'pairs' (take care of using the right Ecoflora codes as described in http://www.ecoflora.co.uk/search_plantchar.php).

Arguments

Format

The format is: a list of the following 17 elements, where each element is a pair of the form "traits":"code used in Ecoflora HTML code":
height_max
: num 3.05
height_min
: num 3.06
leaf_area
: num 3.17
leaf_longevity
: num 3.22
Photosynthetic_pathway
: num 4.02
life_form
: num 5.01
Vegetative_reprod_method
: num 5.05
Flowering_earliest_month
: num 5.07
Flowering_latest_month
: num 5.08
Pollen_vector
: num 5.15
Seed_weight_mean
: num 5.34
Method_of_propagation
: num 5.52
Ellenberg_light_Eco
: num 7.14
Ellenberg_moisture_Eco
: num 7.15
Ellenberg_pH_Eco
: num 7.16
Ellenberg_nitrogen_Eco
: num 7.17
Ellenberg_salt_Eco
: num 7.18

References

Fitter, A . H. and Peat , H. J., 1994, The Ecological Flora Database, J. Ecol., 82, 415-425. http://www.ecoflora.co.uk

Examples

Run this code
## observe the sructure of the dataset
str(traits_eco)

Run the code above in your browser using DataLab