Learn R Programming

TR8 (version 0.9.13)

leda_lookup: List with reference variables needed to download traits from LEDA Traitbase

Description

Contains useful references for the LEDA Traitbase: these data are used by the TR8 package to find URLs of the different .txt files containing the raw data.

Usage

data(leda_lookup)

Arguments

docType

data

source

http://www.leda-traitbase.org/LEDAportal/citation.jsp

References

Please cite the following reference any time you use data retrieved from the LEDA traitbase:

Kleyer, M., Bekker, R.M., Knevel, I.C., Bakker, J.P, Thompson, K., Sonnenschein, M., Poschlod, P., Van Groenendael, J.M., Klimes, L., Klimesova, J., Klotz, S., Rusch, G.M., Hermy, M., Adriaens, D., Boedeltje, G., Bossuyt, B., Dannemann, A., Endels, P., Götzenberger, L., Hodgson, J.G., Jackel, A-K., Kühn, I., Kunzmann, D., Ozinga, W.A., Römermann, C., Stadler, M., Schlegelmilch, J., Steendam, H.J., Tackenberg, O., Wilmann, B., Cornelissen, J.H.C., Eriksson, O., Garnier, E., Peco, B. (2008): The LEDA Traitbase: A database of life-history traits of Northwest European flora. Journal of Ecology 96: 1266-1274.

Examples

Run this code
head(leda_lookup)

Run the code above in your browser using DataLab