traits_eco defines a list containg pairs in the form
short_name_of_the_trait =
corresponding_code_in_Ecoflora At the moment the
package does not download all the traits available at
Ecoflora; curious users can expand the number of
downloadable traits simply extending the list with other
'pairs' (take care of using the right Ecoflora codes
as described in
http://www.ecoflora.co.uk/search_plantchar.php).
## observe the sructure of the dataset
str(traits_eco)
Run the code above in your browser using DataLab