Learn R Programming

TR8 (version 0.8)

traits_special_Biolflor: traits_special_Biolflor

Description

a vector containing traits that can be downloaded from Biolflor for which some special Xpaht rules must be applied

Arguments

docType

data

format

A vector of plant traits

References

Please use the follow citation ay time you use data derived from Biolflor: BIOLFLOR - Eine Datenbank zu biologisch-ökologischen Merkmalen zur Flora von Deutschland. Schriftenreihe für Vegetationskunde 38: 1-333. (Bundesamt für. Bonn, Bundesamt für Naturschutz)

Examples

Run this code
traits_special_Biolflor

Run the code above in your browser using DataLab